# frozen_string_literal: true

require 'rake'
require 'pg'
require 'colorize'
require 'thor'
require 'thor/group'
require 'anonymise/db_faker'
require 'anonymise/version'
require 'anonymise/resource'
module Anonymise
  class Command < Thor
    desc '-v', 'Show Anonymise version'
    map %w[-v --version] => :version

    def version
      say "Anonymise version #{Anonymise::VERSION}"
    end

    desc 'fake',
         'Anonymise Database'
    method_option :db, required: true, type: :string, desc: 'Database name to anonymise'
    method_option :path, required: true, type: :string, desc: 'Anonymisation definitions to apply'
    method_option :user, aliases: 'u', default: 'apps', type: :string, desc: 'User to connect as'
    method_option :password, aliases: 'p', default: 'apps', type: :string, desc: 'Password for user'
    method_option :host, aliases: 'h', default: '127.0.0.1', type: :string, desc: 'Database host address'
    method_option :port, aliases: 'P', default: 5432, type: :numeric, desc: 'Port on host'
    method_option :dry_run, default: false, type: :boolean, desc: 'No apply any changes to the database, just return counts'
    def fake
      db_args = { dbname: options.db, user: options.user,
                  password: options.password, port: options.port,
                  host: options.host }
      puts '*** DRY RUN ***' if options.dry_run
      DbFaker.new(db_args, config(options.path), options.dry_run).fake
    end

    def self.exit_on_failure
      true
    end

    private

    def config(path)
      Resource.new(path).content
    end
  end
end
